@@ -13,23 +13,24 @@
 #'   install_ppverse()
 #' }
 #' @export
-install_ppverse <- function(pkgs = pkgs_ppverse(free_libre_only), 
-                            ..., 
-                            dependencies = TRUE, 
-                            free_libre_only = TRUE) {
-    repos <- c(piecepackr = "https://piecepackr.r-universe.dev/",
-               getOption("repos"))
-    utils::install.packages(pkgs, ..., repos = repos, dependencies = dependencies)
+install_ppverse <- function(
+	pkgs = pkgs_ppverse(free_libre_only),
+	...,
+	dependencies = TRUE,
+	free_libre_only = TRUE
+) {
+	repos <- c(piecepackr = "https://piecepackr.r-universe.dev/", getOption("repos"))
+	utils::install.packages(pkgs, ..., repos = repos, dependencies = dependencies)
 }
 
 #' @rdname install_ppverse
 #' @param free_libre_only Flag to only include packages that are Free/Libre Open Source.
 #' @export
 pkgs_ppverse <- function(free_libre_only = TRUE) {
-    pkgs <- c("piecepackr", "pprules", "ppcli", "ppgamer", "ppn", "ppdf")
-    if (isFALSE(free_libre_only)) {
-        pkgs <- append(pkgs, c("piecenikr"))
-    }
-    pkgs <- sort(pkgs)
-    pkgs
+	pkgs <- c("piecepackr", "pprules", "ppcli", "ppgamer", "ppn", "ppdf")
+	if (isFALSE(free_libre_only)) {
+		pkgs <- append(pkgs, c("piecenikr"))
+	}
+	pkgs <- sort(pkgs)
+	pkgs
 }
